Attribute VB_Name = "Globals"
' $Id: Globals.bas,v 1.9 2009-09-29 10:49:38 dcharlton Exp $
' Various tables to map CSMail/SSL constants to strings
'
' ----------------------------------------------------------------------------
' Note: I've tried to organise this sample so that the CSMail/SSL
' specific code is in:
'
'   SMTP_Test.cls   -   secure SMTP connection
'   POP3_Test.cls   -   secure POP3 connection
'
' Code in any other files is just string and sealing wax to hold
' the sample together
' ----------------------------------------------------------------------------

Option Explicit

Declare Function SendMessage Lib "User" (ByVal hWnd As Integer, ByVal wMsg As Integer, ByVal wParam As Integer, lParam As Any) As Long


Dim v As Variant

Type LookupEntry
    Value As Long
    Text As String
End Type

Public Protocol(3) As LookupEntry
Public Cipher(3) As LookupEntry
Public Hash(1) As LookupEntry
Public Exchange(2) As LookupEntry
Public SSLFlags(9)  As LookupEntry
Public LogFacilities(3) As LookupEntry
Public CSMailErrors(29) As LookupEntry
Public CSMailExErrors(25) As LookupEntry

Sub InitLookups()

' Init protocol lookup table
With Protocol(0): .Value = SSL_TLS1: .Text = "TLS version 1.0": End With
With Protocol(1): .Value = SSL_SSL3: .Text = "SSL version 3.0": End With
With Protocol(2): .Value = SSL_SSL2: .Text = "SSL version 2.0": End With
With Protocol(3): .Value = SSL_PCT1: .Text = "PCT version 1.0": End With

' Init cipher lookup table
With Cipher(0): .Value = SSL_RC2: .Text = "RC2 block encryption": End With
With Cipher(1): .Value = SSL_RC4: .Text = "RC4 stream encryption": End With
With Cipher(2): .Value = SSL_DES: .Text = "DES encryption": End With
With Cipher(3): .Value = SSL_SKIPJACK: .Text = "Skipjack block encryption": End With

' Init hash lookup table
With Hash(0): .Value = SSL_MD5: .Text = "MD5 hashing algorithm": End With
With Hash(1): .Value = SSL_SHA: .Text = "SHA hashing algorithm": End With

' Init exchange lookup table
With Exchange(0): .Value = SSL_RSA: .Text = "RSA key exchange": End With
With Exchange(1): .Value = SSL_DH: .Text = "Diffie-Hellman key exchange": End With
With Exchange(2): .Value = SSL_KEA: .Text = "Fortezza": End With

' Init flags lookup table
With SSLFlags(0): .Value = SSLNoServerNameCheck: .Text = "SSLNoServerNameCheck": End With
With SSLFlags(1): .Value = SSLNoServerCertificateValidation: .Text = "SSLNoServerCertificateValidation": End With
With SSLFlags(2): .Value = SSLRevocationCheckAll: .Text = "SSLRevocationCheckAll": End With
With SSLFlags(3): .Value = SSLRevocationCheckEnd: .Text = "SSLRevocationCheckEnd": End With
With SSLFlags(4): .Value = SSLRevocationExcludeRoot: .Text = "SSLRevocationExcludeRoot": End With
With SSLFlags(5): .Value = SSLRevocationIgnoreNRC: .Text = "SSLRevocationIgnoreNRC": End With
With SSLFlags(6): .Value = SSLRevocationIgnoreRO: .Text = "SSLRevocationIgnoreRO": End With
With SSLFlags(7): .Value = SSLConfidentiality: .Text = "SSLConfidentiality": End With
With SSLFlags(8): .Value = SSLNoDefaultCredentials: .Text = "SSLNoDefaultCredentials": End With
With SSLFlags(9): .Value = SSLNoDefaultCredentialsHard: .Text = "SSLNoDefaultCredentialsHard": End With

With CSMailErrors(0): .Value = errSMTPFromTooMany: .Text = "errSMTPFromTooMany": End With
With CSMailErrors(1): .Value = errSMTPFromSyntax: .Text = "errSMTPFromSyntax": End With
With CSMailErrors(2): .Value = errSMTPFromTooMany: .Text = "errSMTPFromTooMany": End With
With CSMailErrors(3): .Value = errSMTPSenderTooMany: .Text = "errSMTPSenderTooMany": End With
With CSMailErrors(4): .Value = errSMTPSenderSyntax: .Text = "errSMTPSenderSyntax": End With
With CSMailErrors(5): .Value = errSMTPOrSocket: .Text = "errSMTPOrSocket": End With
With CSMailErrors(6): .Value = errConnect: .Text = "errConnect": End With
With CSMailErrors(7): .Value = errSMTP: .Text = "errSMTP": End With
With CSMailErrors(8): .Value = errSocket: .Text = "errSocket": End With
With CSMailErrors(9): .Value = errFileNotFound: .Text = "errFileNotFound": End With
With CSMailErrors(10): .Value = errIndex: .Text = "errIndex": End With
With CSMailErrors(11): .Value = errInvalidAddress: .Text = "errInvalidAddress": End With
With CSMailErrors(12): .Value = errPOP: .Text = "errPOP": End With
With CSMailErrors(13): .Value = errInternalParseField: .Text = "errInternalParseField": End With
With CSMailErrors(14): .Value = errInvalidContentType: .Text = "errInvalidContentType": End With
With CSMailErrors(15): .Value = errAllreadyConnected: .Text = "errAllreadyConnected": End With
With CSMailErrors(15): .Value = errBusySending: .Text = "errBusySending": End With
With CSMailErrors(16): .Value = errSocketSending: .Text = "errSocketSending": End With
With CSMailErrors(17): .Value = errInvalidDisposition: .Text = "errInvalidDisposition": End With
With CSMailErrors(18): .Value = errESMTP: .Text = "errESMTP": End With
With CSMailErrors(19): .Value = errESMTP_AUTH: .Text = "errESMTP_AUTH": End With
With CSMailErrors(20): .Value = errSOCKS4: .Text = "errSOCKS4": End With
With CSMailErrors(21): .Value = errSOCKS5: .Text = "errSOCKS5": End With
With CSMailErrors(22): .Value = errInvalidProxyType: .Text = "errInvalidProxyType": End With
With CSMailErrors(23): .Value = errNoCodepage: .Text = "errNoCodepage": End With
With CSMailErrors(24): .Value = errNoCharset: .Text = "errNoCharset": End With
With CSMailErrors(25): .Value = errPOP3QuickConnectStat: .Text = "errPOP3QuickConnectStat": End With
With CSMailErrors(26): .Value = errPOP3ServerClosedPort: .Text = "errPOP3ServerClosedPort": End With
With CSMailErrors(27): .Value = errTimeout: .Text = "errTimeout": End With
With CSMailErrors(28): .Value = errBadHandler: .Text = "errBadHandler": End With
With CSMailErrors(29): .Value = errSSL: .Text = "errSSL": End With

With CSMailExErrors(0): .Value = eexProxyNoconn: .Text = "eexProxyNoconn": End With
With CSMailExErrors(1): .Value = eexProxySocketerror: .Text = "eexProxySocketerror": End With
With CSMailExErrors(2): .Value = eexProxyServerclosedport: .Text = "eexProxyServerclosedport": End With
With CSMailExErrors(3): .Value = eexProxyException: .Text = "eexProxyException": End With
With CSMailExErrors(4): .Value = eexProxyUnexpecteddefault: .Text = "eexProxyUnexpecteddefault": End With
With CSMailExErrors(5): .Value = eexProxyRequestfailed: .Text = "eexProxyRequestfailed": End With
With CSMailExErrors(6): .Value = eexProxyAuthrequired: .Text = "eexProxyAuthrequired": End With
With CSMailExErrors(7): .Value = eexProxyAuthtypeunknown: .Text = "eexProxyAuthtypeunknown": End With
With CSMailExErrors(8): .Value = eexProxyAuthfailed: .Text = "eexProxyAuthfailed": End With
With CSMailExErrors(9): .Value = eexProxyAuthnologon: .Text = "eexProxyAuthnologon": End With
With CSMailExErrors(10): .Value = eexNoExtended: .Text = "eexNoextended": End With
With CSMailExErrors(11): .Value = eexDNS: .Text = "eexDNS": End With
With CSMailExErrors(12): .Value = eexTCPConnect: .Text = "eexTCPConnect": End With
With CSMailExErrors(13): .Value = eexPopServer: .Text = "eexPopserver": End With
With CSMailExErrors(14): .Value = eexSocketTx: .Text = "eexSocketTx": End With
With CSMailExErrors(15): .Value = eexSocketRx: .Text = "eexSocketRx": End With
With CSMailExErrors(16): .Value = eexSocket: .Text = "eexSocket": End With
With CSMailExErrors(17): .Value = eexNotConnected: .Text = "eexNotconnected": End With
With CSMailExErrors(18): .Value = eexSmtpServer: .Text = "eexSmtpServer": End With
With CSMailExErrors(19): .Value = eexSSLW32: .Text = "eexSSLW32": End With
With CSMailExErrors(20): .Value = eexSSLConnected: .Text = "eexSSLConnected": End With
With CSMailExErrors(21): .Value = eexSSLNocontext: .Text = "eexSSLNocontext": End With
With CSMailExErrors(22): .Value = eexSSLCertName: .Text = "eexSSLCertName": End With
With CSMailExErrors(23): .Value = eexSSLProtocol: .Text = "eexSSLProtocol": End With
With CSMailExErrors(24): .Value = eexSSLCertificate: .Text = "eexSSLCertificate": End With
With CSMailExErrors(25): .Value = eexSSLRevoke: .Text = "eexSSLRevoke": End With



' Init facility lookup table
With LogFacilities(0): .Value = LOG_F_SSL: .Text = "SSL": End With
With LogFacilities(1): .Value = LOG_F_PROTOCOL: .Text = "PRO": End With
With LogFacilities(2): .Value = LOG_F_USER: .Text = "USR": End With
With LogFacilities(3): .Value = LOG_F_DATA: .Text = "DAT": End With


End Sub

Function LookupTextById(Table() As LookupEntry, Id As Long) As String

Dim i As Integer

For i = LBound(Table) To UBound(Table)
    If Table(i).Value = Id Then
        LookupTextById = Table(i).Text
        Exit Function
    End If
Next

LookupTextById = "N/A"

End Function








